@@ -5,11 +5,12 @@ use warnings;
 
 use base 'SVN::Web::action';
 
+use Encode ();
 use SVN::Ra;
 use SVN::Client;
 use SVN::Web::X;
 
-our $VERSION = 0.53;
+our $VERSION = 0.62;
 
 =head1 NAME
 
@@ -143,63 +144,53 @@ sub cache_key {
 
 sub run {
     my $self = shift;
-    my $ctx  = $self->{repos}{client};
-    my $ra   = $self->{repos}{ra};
-    my $path = $self->{path};
-
-    my $uri =
-        $path eq '/'
-      ? $self->{repos}{uri}
-      : $self->{repos}{uri} . $path;
+    my $uri = $self->{repos}{uri};
+    $uri .= '/'.$self->rpath if $self->rpath;
 
     my ( $exp_rev, $yng_rev, $act_rev, $at_head ) = $self->get_revs();
 
     my $rev = $act_rev;
 
-    my $node_kind;
-    $ctx->info( $uri, $rev, $rev, sub { $node_kind = $_[1]->kind(); }, 0 );
+    my $node_kind = $self->svn_get_node_kind($uri, $rev, $rev);
 
     if ( $node_kind == $SVN::Node::none ) {
         SVN::Web::X->throw(
             error => '(path %1 does not exist in revision %2)',
-            vars  => [ $path, $rev ]
+            vars  => [ $self->rpath, $rev ]
         );
     }
 
     if ( $node_kind != $SVN::Node::dir ) {
         SVN::Web::X->throw(
             error => '(path %1 is not a directory in revision %2)',
-            vars  => [ $path, $rev ],
+            vars  => [ $self->rpath, $rev ],
         );
     }
 
-    my $dirents = $ctx->ls( $uri, $rev, 0 );
+    my $dirents = $self->ctx_ls( $uri, $rev, 0 );
 
     my $entries = [];
     my ( $name, $dirent );
     my $current_time = time();
 
+    my $base_path = $self->rpath;
     while ( ( $name, $dirent ) = each %{$dirents} ) {
-        my $kind = $dirent->kind();
-        my $entry_path = 
-          $path eq '/'
-          ? "$path$name"
-          : "$path/$name";
+        my $node_kind = $dirent->kind();
 
-        my @log_result = $self->recent_interesting_rev( $entry_path, $rev );
+        my @log_result = $self->recent_interesting_rev( "$base_path/$name", $rev );
 
         push @{$entries},
           {
             name      => $name,
             rev       => $log_result[1],
-            kind      => $kind,
-            isdir     => ( $kind == $SVN::Node::dir ),
-            size      => ( $kind == $SVN::Node::dir ? '' : $dirent->size() ),
+            kind      => $node_kind,
+            isdir     => ( $node_kind == $SVN::Node::dir ),
+            size      => ( $node_kind == $SVN::Node::dir ? '' : $dirent->size() ),
             author    => $dirent->last_author(),
             has_props => $dirent->has_props(),
             time      => $dirent->time() / 1_000_000,
             age => $current_time - ( $dirent->time() / 1_000_000 ),
-            msg => $log_result[4],
+            msg => Encode::decode('utf8',$log_result[4]),
           };
     }
 
@@ -210,7 +201,7 @@ sub run {
 
     my @props = ();
     foreach my $prop_name (qw(svn:externals)) {
-        my $prop_value = ( $ctx->revprop_get( $prop_name, $uri, $rev ) )[0];
+        my $prop_value = ( $self->ctx_revprop_get( $prop_name, $uri, $rev ) )[0];
         if ( defined $prop_value ) {
             $prop_value =~ s/\s*\n$//ms;
             push @props, { name => $prop_name, value => $prop_value };
